@@ -20,14 +20,14 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <Lum/Dlg/ActionDialog.h>
+
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/Dialog.h>
-
 #include "Configuration.h"
 
 class ValuesModel : public Lum::Model::StdRefTable<Value,std::vector<Value> >
@@ -52,7 +52,7 @@ public:
 
 typedef Lum::Base::Reference<ValuesModel> ValuesModelRef;
 
-class DiceEdit : public Lum::Dialog
+class DiceEdit : public Lum::Dlg::ActionDialog
 {
 private:
   Dice&                              dice;
@@ -61,17 +61,26 @@ private:
 
   Lum::Model::SingleLineSelectionRef selection;
 
+  Lum::Model::ActionRef              okAction;
   Lum::Model::ActionRef              addAction;
   Lum::Model::ActionRef              addNumbersAction;
   Lum::Model::ActionRef              editAction;
   Lum::Model::ActionRef              removeAction;
 
+  bool                               success;
+
+private:
+  void EvaluateRights();
+
 public:
   DiceEdit(Dice& dice);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
+
+  bool GetSuccess() const;
 };
 
 #endif
