@@ -36,8 +36,7 @@ DiceSetList::DiceSetList()
    editAction(new Lum::Model::Action()),
    removeAction(new Lum::Model::Action())
 {
-  editAction->Disable();
-  removeAction->Disable();
+  EvaluateRights();
 
   Observe(selection);
 
@@ -48,13 +47,25 @@ DiceSetList::DiceSetList()
   Observe(GetClosedAction());
 }
 
-void DiceSetList::PreInit()
+void DiceSetList::EvaluateRights()
+{
+  if (selection.Valid() && selection->HasSelection()) {
+    editAction->Enable();
+    removeAction->Enable();
+  }
+  else {
+    editAction->Disable();
+    removeAction->Disable();
+  }
+}
+
+Lum::Object* DiceSetList::GetContent()
 {
   Lum::Panel            *panel,*horiz;
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
-  panel=Lum::VPanel::Create();
+  panel=Lum::VPanel::Create(true,true);
 
   horiz=Lum::HPanel::Create(true,true);
 
@@ -63,7 +74,7 @@ void DiceSetList::PreInit()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetHeight(Lum::Base::Size::stdCharHeight,8);
+  table->SetHeight(Lum::Base::Size::stdCharHeight,10);
   table->SetShowHeader(true);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
@@ -82,12 +93,13 @@ void DiceSetList::PreInit()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
   panel->Add(horiz);
-  panel->AddSpace();
-  panel->Add(Lum::ButtonRow::CreateOk(GetClosedAction(),true,false));
 
-  SetMain(panel);
+  return panel;
+}
 
-  Dialog::PreInit();
+void DiceSetList::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  Lum::Dlg::ActionDialog::CreateActionInfosOk(actions,GetClosedAction());
 }
 
 void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -96,14 +108,7 @@ void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
     Exit();
   }
   else if (model==selection && dynamic_cast<const Lum::Model::Selection::Selected*>(&msg)!=NULL) {
-    if (selection->HasSelection()) {
-      editAction->Enable();
-      removeAction->Enable();
-    }
-    else {
-      editAction->Disable();
-      removeAction->Disable();
-    }
+    EvaluateRights();
   }
   else if (model==addAction && addAction->IsFinished()) {
     DiceSetEdit *dialog;
@@ -119,14 +124,14 @@ void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
       if (dialog->GetResult()) {
         // Redraw entry because its name has changed...
         setsModel->Append(diceSet);
+        EvaluateRights();
+        configurationChanged=true;
       }
     }
 
     delete dialog;
-
-    configurationChanged=true;
   }
-  else if (model==editAction && editAction->IsFinished()) {
+  else if (model==editAction && editAction->IsFinished() && editAction->IsEnabled()) {
     assert(selection->HasSelection());
 
     DiceSetEdit *dialog;
@@ -140,21 +145,21 @@ void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
       if (dialog->GetResult()) {
         // Redraw entry because its name has changed...
         setsModel->RedrawRow(selection->GetLine());
+        EvaluateRights();
+        configurationChanged=true;
       }
     }
 
     delete dialog;
-
-    configurationChanged=true;
   }
-  else if (model==removeAction && removeAction->IsFinished()) {
+  else if (model==removeAction && removeAction->IsFinished() && removeAction->IsEnabled()) {
     assert(selection->HasSelection());
 
     setsModel->Delete(selection->GetLine());
-
+    EvaluateRights();
     configurationChanged=true;
   }
 
-  Dialog::Resync(model,msg);
+  Lum::Dlg::ActionDialog::Resync(model,msg);
 }
 
