@@ -25,7 +25,8 @@
 
 #include "Configuration.h"
 
-#include <iostream>
+static size_t diceFrame = 3;
+
 GameArea::GameArea(bool horizontalFlex, bool verticalFlex)
  : area(NULL),
    backgroundColor(0.0,0.5,0.0,Lum::OS::display->GetColor(Lum::OS::Display::backgroundColor)),
@@ -112,12 +113,14 @@ void GameArea::RedrawArea()
     else {
       draw->PushForeground(normalFrameColor);
     }
+
+    draw->PushPen(diceFrame,Lum::OS::DrawInfo::penNormal);
     draw->DrawRectangle(x,y,cellSize,cellSize);
-    draw->DrawRectangle(x+1,y+1,cellSize-2,cellSize-2);
     draw->PopForeground();
+    draw->PopPen();
 
     draw->PushForeground(cellBackgroundColor);
-    draw->FillRectangle(x+2,y+2,cellSize-4,cellSize-4);
+    draw->FillRectangle(x+diceFrame,y+diceFrame,cellSize-2*diceFrame,cellSize-2*diceFrame);
     draw->PopForeground();
 
     if (!dice->value.empty()) {
@@ -187,12 +190,10 @@ void GameArea::CalcAreaSize()
 
   cellSize+=2*std::max(Lum::OS::display->GetSpaceHorizontal(Lum::OS::Display::spaceObjectBorder),
                        Lum::OS::display->GetSpaceVertical(Lum::OS::Display::spaceObjectBorder));
-  cellSize+=4; // Frame around the dice
+  cellSize+=2*diceFrame; // Frame around the dice
 
   cellSize=std::max(cellSize,(size_t)Lum::Base::GetSize(Lum::Base::Size::mm,9));
 
-  std::cout << "Current cell size: " << cellSize << std::endl;
-
   columns=0;
 
   //
@@ -284,7 +285,7 @@ void GameArea::CalcSize()
 
   cellSize+=2*std::max(Lum::OS::display->GetSpaceHorizontal(Lum::OS::Display::spaceObjectBorder),
                        Lum::OS::display->GetSpaceVertical(Lum::OS::Display::spaceObjectBorder));
-  cellSize+=4; // Frame around the dice
+  cellSize+=2*diceFrame; // Frame around the dice
 
   // For finger usablility dices should hvae at least 9 mm size
   cellSize=std::max(cellSize,(size_t)Lum::Base::GetSize(Lum::Base::Size::mm,9));
